import OCP.IFGraph
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.Standard
import OCP.Interface
import OCP.TColStd
__all__  = [
"IFGraph_AllConnected",
"IFGraph_AllShared",
"IFGraph_Articulations",
"IFGraph_Compare",
"IFGraph_SubPartsIterator",
"IFGraph_Cumulate",
"IFGraph_Cycles",
"IFGraph_ExternalSources",
"IFGraph_StrongComponants",
"IFGraph_SCRoots",
"IFGraph_ConnectedComponants"
]
class IFGraph_AllConnected(OCP.Interface.Interface_GraphContent, OCP.Interface.Interface_EntityIterator):
    """
    this class gives content of the CONNECTED COMPONENT(S) which include specific Entity(ies)
    """
    def AddItem(self,anentity : OCP.Standard.Standard_Transient) -> None: 
        """
        Adds to the iteration list a defined entity
        """
    def AddList(self,list : OCP.TColStd.TColStd_HSequenceOfTransient) -> None: 
        """
        Gets a list of entities and adds its to the iteration list
        """
    def Begin(self) -> None: 
        """
        Does the Evaluation before starting the iteration itself (in out)
        """
    def Content(self) -> OCP.TColStd.TColStd_HSequenceOfTransient: 
        """
        Returns the content of the Iterator, accessed through a Handle to be used by a frontal-engine logic Returns an empty Sequence if the Iterator is empty Calls Start if not yet done
        """
    def Destroy(self) -> None: 
        """
        Clears data of iteration
        """
    def Evaluate(self) -> None: 
        """
        does the specific evaluation (Connected entities atall levels)
        """
    def GetFromEntity(self,ent : OCP.Standard.Standard_Transient) -> None: 
        """
        adds an entity and its Connected ones to the list (allows to cumulate all Entities Connected by some ones) Note that if "ent" is in the already computed list,, no entity will be added, but if "ent" is not already in the list, a new Connected Component will be cumulated
        """
    @overload
    def GetFromGraph(self,agraph : OCP.Interface.Interface_Graph) -> None: 
        """
        Gets all Entities designated by a Graph (once created), adds them to those already recorded

        Gets entities from a graph which have a specific Status value (one created), adds them to those already recorded
        """
    @overload
    def GetFromGraph(self,agraph : OCP.Interface.Interface_Graph,stat : int) -> None: ...
    def GetOneItem(self,anentity : OCP.Standard.Standard_Transient) -> None: 
        """
        same as AddItem (kept for compatibility)
        """
    def More(self) -> bool: 
        """
        Says if there are other entities (vertices) to iterate the first time, calls Start
        """
    def NbEntities(self) -> int: 
        """
        Returns count of entities which will be iterated on Calls Start if not yet done
        """
    def NbTyped(self,type : OCP.Standard.Standard_Type) -> int: 
        """
        Returns count of entities of a given type (kind of)
        """
    def Next(self) -> None: 
        """
        Sets iteration to the next entity (vertex) to give
        """
    def ResetData(self) -> None: 
        """
        Allows to restart on a new data set
        """
    def Result(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns Result under the exact form of an EntityIterator : Can be used when EntityIterator itself is required (as a returned value for instance), without way for a sub-class
        """
    def SelectType(self,atype : OCP.Standard.Standard_Type,keep : bool) -> None: 
        """
        Selects entities with are Kind of a given type, keep only them (is keep is True) or reject only them (if keep is False)
        """
    def Start(self) -> None: 
        """
        Allows re-iteration (useless for the first iteration)
        """
    def Typed(self,type : OCP.Standard.Standard_Type) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns the list of entities of a given type (kind of)
        """
    def Value(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns the current Entity iterated, to be used by Interface tools
        """
    @overload
    def __init__(self,agraph : OCP.Interface.Interface_Graph) -> None: ...
    @overload
    def __init__(self,agraph : OCP.Interface.Interface_Graph,ent : OCP.Standard.Standard_Transient) -> None: ...
    pass
class IFGraph_AllShared(OCP.Interface.Interface_GraphContent, OCP.Interface.Interface_EntityIterator):
    """
    this class determines all Entities shared by some specific ones, at any level (those which will be lead in a Transfer for instance)
    """
    def AddItem(self,anentity : OCP.Standard.Standard_Transient) -> None: 
        """
        Adds to the iteration list a defined entity
        """
    def AddList(self,list : OCP.TColStd.TColStd_HSequenceOfTransient) -> None: 
        """
        Gets a list of entities and adds its to the iteration list
        """
    def Begin(self) -> None: 
        """
        Does the Evaluation before starting the iteration itself (in out)
        """
    def Content(self) -> OCP.TColStd.TColStd_HSequenceOfTransient: 
        """
        Returns the content of the Iterator, accessed through a Handle to be used by a frontal-engine logic Returns an empty Sequence if the Iterator is empty Calls Start if not yet done
        """
    def Destroy(self) -> None: 
        """
        Clears data of iteration
        """
    def Evaluate(self) -> None: 
        """
        does the specific evaluation (shared entities atall levels)
        """
    def GetFromEntity(self,ent : OCP.Standard.Standard_Transient) -> None: 
        """
        adds an entity and its shared ones to the list (allows to cumulate all Entities shared by some ones)
        """
    @overload
    def GetFromGraph(self,agraph : OCP.Interface.Interface_Graph) -> None: 
        """
        Gets all Entities designated by a Graph (once created), adds them to those already recorded

        Gets entities from a graph which have a specific Status value (one created), adds them to those already recorded
        """
    @overload
    def GetFromGraph(self,agraph : OCP.Interface.Interface_Graph,stat : int) -> None: ...
    def GetFromIter(self,iter : OCP.Interface.Interface_EntityIterator) -> None: 
        """
        Adds Entities from an EntityIterator and all their shared ones at any level
        """
    def GetOneItem(self,anentity : OCP.Standard.Standard_Transient) -> None: 
        """
        same as AddItem (kept for compatibility)
        """
    def More(self) -> bool: 
        """
        Says if there are other entities (vertices) to iterate the first time, calls Start
        """
    def NbEntities(self) -> int: 
        """
        Returns count of entities which will be iterated on Calls Start if not yet done
        """
    def NbTyped(self,type : OCP.Standard.Standard_Type) -> int: 
        """
        Returns count of entities of a given type (kind of)
        """
    def Next(self) -> None: 
        """
        Sets iteration to the next entity (vertex) to give
        """
    def ResetData(self) -> None: 
        """
        Allows to restart on a new data set
        """
    def Result(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns Result under the exact form of an EntityIterator : Can be used when EntityIterator itself is required (as a returned value for instance), without way for a sub-class
        """
    def SelectType(self,atype : OCP.Standard.Standard_Type,keep : bool) -> None: 
        """
        Selects entities with are Kind of a given type, keep only them (is keep is True) or reject only them (if keep is False)
        """
    def Start(self) -> None: 
        """
        Allows re-iteration (useless for the first iteration)
        """
    def Typed(self,type : OCP.Standard.Standard_Type) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns the list of entities of a given type (kind of)
        """
    def Value(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns the current Entity iterated, to be used by Interface tools
        """
    @overload
    def __init__(self,agraph : OCP.Interface.Interface_Graph) -> None: ...
    @overload
    def __init__(self,agraph : OCP.Interface.Interface_Graph,ent : OCP.Standard.Standard_Transient) -> None: ...
    pass
class IFGraph_Articulations(OCP.Interface.Interface_GraphContent, OCP.Interface.Interface_EntityIterator):
    """
    this class gives entities which are Articulation points in a whole Model or in a sub-part An Articulation Point divides the graph in two (or more) disconnected sub-graphs Identifying Articulation Points allows improving efficiency of splitting a set of Entities into sub-sets
    """
    def AddItem(self,anentity : OCP.Standard.Standard_Transient) -> None: 
        """
        Adds to the iteration list a defined entity
        """
    def AddList(self,list : OCP.TColStd.TColStd_HSequenceOfTransient) -> None: 
        """
        Gets a list of entities and adds its to the iteration list
        """
    def Begin(self) -> None: 
        """
        Does the Evaluation before starting the iteration itself (in out)
        """
    def Content(self) -> OCP.TColStd.TColStd_HSequenceOfTransient: 
        """
        Returns the content of the Iterator, accessed through a Handle to be used by a frontal-engine logic Returns an empty Sequence if the Iterator is empty Calls Start if not yet done
        """
    def Destroy(self) -> None: 
        """
        Clears data of iteration
        """
    def Evaluate(self) -> None: 
        """
        Evaluates the list of Articulation points
        """
    def GetFromEntity(self,ent : OCP.Standard.Standard_Transient) -> None: 
        """
        adds an entity and its shared ones to the list
        """
    @overload
    def GetFromGraph(self,agraph : OCP.Interface.Interface_Graph) -> None: 
        """
        Gets all Entities designated by a Graph (once created), adds them to those already recorded

        Gets entities from a graph which have a specific Status value (one created), adds them to those already recorded
        """
    @overload
    def GetFromGraph(self,agraph : OCP.Interface.Interface_Graph,stat : int) -> None: ...
    def GetFromIter(self,iter : OCP.Interface.Interface_EntityIterator) -> None: 
        """
        adds a list of entities (as an iterator)
        """
    def GetOneItem(self,anentity : OCP.Standard.Standard_Transient) -> None: 
        """
        same as AddItem (kept for compatibility)
        """
    def More(self) -> bool: 
        """
        Says if there are other entities (vertices) to iterate the first time, calls Start
        """
    def NbEntities(self) -> int: 
        """
        Returns count of entities which will be iterated on Calls Start if not yet done
        """
    def NbTyped(self,type : OCP.Standard.Standard_Type) -> int: 
        """
        Returns count of entities of a given type (kind of)
        """
    def Next(self) -> None: 
        """
        Sets iteration to the next entity (vertex) to give
        """
    def ResetData(self) -> None: 
        """
        Allows to restart on a new data set
        """
    def Result(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns Result under the exact form of an EntityIterator : Can be used when EntityIterator itself is required (as a returned value for instance), without way for a sub-class
        """
    def SelectType(self,atype : OCP.Standard.Standard_Type,keep : bool) -> None: 
        """
        Selects entities with are Kind of a given type, keep only them (is keep is True) or reject only them (if keep is False)
        """
    def Start(self) -> None: 
        """
        Allows re-iteration (useless for the first iteration)
        """
    def Typed(self,type : OCP.Standard.Standard_Type) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns the list of entities of a given type (kind of)
        """
    def Value(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns the current Entity iterated, to be used by Interface tools
        """
    def __init__(self,agraph : OCP.Interface.Interface_Graph,whole : bool) -> None: ...
    pass
class IFGraph_Compare(OCP.Interface.Interface_GraphContent, OCP.Interface.Interface_EntityIterator):
    """
    this class evaluates effect of two compared sub-parts : cumulation (union), common part (intersection-overlapping) part specific to first sub-part or to the second one Results are kept in a Graph, several question can be set Basic Iteration gives Cumulation (union)
    """
    def AddItem(self,anentity : OCP.Standard.Standard_Transient) -> None: 
        """
        Adds to the iteration list a defined entity
        """
    def AddList(self,list : OCP.TColStd.TColStd_HSequenceOfTransient) -> None: 
        """
        Gets a list of entities and adds its to the iteration list
        """
    def Begin(self) -> None: 
        """
        Does the Evaluation before starting the iteration itself (in out)
        """
    def Common(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        returns entities common to the both parts
        """
    def Content(self) -> OCP.TColStd.TColStd_HSequenceOfTransient: 
        """
        Returns the content of the Iterator, accessed through a Handle to be used by a frontal-engine logic Returns an empty Sequence if the Iterator is empty Calls Start if not yet done
        """
    def Destroy(self) -> None: 
        """
        Clears data of iteration
        """
    def Evaluate(self) -> None: 
        """
        Recomputes result of comparing to sub-parts
        """
    def FirstOnly(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        returns entities which are exclusively in the first list
        """
    def GetFromEntity(self,ent : OCP.Standard.Standard_Transient,first : bool) -> None: 
        """
        adds an entity and its shared ones to the list : first True means adds to the first sub-list, else to the 2nd
        """
    @overload
    def GetFromGraph(self,agraph : OCP.Interface.Interface_Graph) -> None: 
        """
        Gets all Entities designated by a Graph (once created), adds them to those already recorded

        Gets entities from a graph which have a specific Status value (one created), adds them to those already recorded
        """
    @overload
    def GetFromGraph(self,agraph : OCP.Interface.Interface_Graph,stat : int) -> None: ...
    def GetFromIter(self,iter : OCP.Interface.Interface_EntityIterator,first : bool) -> None: 
        """
        adds a list of entities (as an iterator) as such, that is, their shared entities are not considered (use AllShared to have them) first True means adds to the first sub-list, else to the 2nd
        """
    def GetOneItem(self,anentity : OCP.Standard.Standard_Transient) -> None: 
        """
        same as AddItem (kept for compatibility)
        """
    def KeepCommon(self) -> None: 
        """
        Keeps only Common part, sets it as First list and clears second list
        """
    def Merge(self) -> None: 
        """
        merges the second list into the first one, hence the second list is empty
        """
    def More(self) -> bool: 
        """
        Says if there are other entities (vertices) to iterate the first time, calls Start
        """
    def NbEntities(self) -> int: 
        """
        Returns count of entities which will be iterated on Calls Start if not yet done
        """
    def NbTyped(self,type : OCP.Standard.Standard_Type) -> int: 
        """
        Returns count of entities of a given type (kind of)
        """
    def Next(self) -> None: 
        """
        Sets iteration to the next entity (vertex) to give
        """
    def RemoveSecond(self) -> None: 
        """
        Removes the contents of second list
        """
    def ResetData(self) -> None: 
        """
        Allows to restart on a new data set
        """
    def Result(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns Result under the exact form of an EntityIterator : Can be used when EntityIterator itself is required (as a returned value for instance), without way for a sub-class
        """
    def SecondOnly(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        returns entities which are exclusively in the second part
        """
    def SelectType(self,atype : OCP.Standard.Standard_Type,keep : bool) -> None: 
        """
        Selects entities with are Kind of a given type, keep only them (is keep is True) or reject only them (if keep is False)
        """
    def Start(self) -> None: 
        """
        Allows re-iteration (useless for the first iteration)
        """
    def Typed(self,type : OCP.Standard.Standard_Type) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns the list of entities of a given type (kind of)
        """
    def Value(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns the current Entity iterated, to be used by Interface tools
        """
    def __init__(self,agraph : OCP.Interface.Interface_Graph) -> None: ...
    pass
class IFGraph_SubPartsIterator():
    """
    defines general form for graph classes of which result is not a single iteration on Entities, but a nested one : External iteration works on sub-parts, identified by each class (according to its algorithm) Internal Iteration concerns Entities of a sub-part Sub-Parts are assumed to be disjoined; if they are not, the first one has priority
    """
    def AddPart(self) -> None: 
        """
        Adds an empty part and sets it to receive entities
        """
    def Entities(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns current sub-part, not as a "Value", but as an Iterator on Entities it contains Error : same as above (end of iteration)
        """
    def EntityPartNum(self,ent : OCP.Standard.Standard_Transient) -> int: 
        """
        Returns number of the sub-part in which an Entity has been set if it is not in a sub-part (or not loaded at all), Returns 0
        """
    def Evaluate(self) -> None: 
        """
        Called by Clear, this method allows evaluation just before iteration; its default is doing nothing, it is designed to be redefined
        """
    def FirstEntity(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns the first entity of current sub-part, that is for a Single one, the only one it contains Error : same as above (end of iteration)
        """
    def GetFromEntity(self,ent : OCP.Standard.Standard_Transient,shared : bool) -> None: 
        """
        Adds an Entity : into load status if in Load mode, to the current part if there is one. If shared is True, adds also its shared ones (shared at all levels)
        """
    def GetFromIter(self,iter : OCP.Interface.Interface_EntityIterator) -> None: 
        """
        Adds a list of Entities (into Load mode or to a Part), given as an Iterator
        """
    def GetParts(self,other : IFGraph_SubPartsIterator) -> None: 
        """
        Gets Parts from another SubPartsIterator (in addition to the ones already recorded) Error if both SubPartsIterators are not based on the same Model
        """
    def IsInPart(self,ent : OCP.Standard.Standard_Transient) -> bool: 
        """
        Returns True if an Entity is Present in a sub-part
        """
    def IsLoaded(self,ent : OCP.Standard.Standard_Transient) -> bool: 
        """
        Returns True if an Entity is loaded (either set into a sub-part or not)
        """
    def IsSingle(self) -> bool: 
        """
        Returns True if current sub-part is single (has only one Entity) Error if there is no sub-part to iterate now
        """
    def Loaded(self) -> OCP.Interface.Interface_GraphContent: 
        """
        Returns entities which where loaded (not set into a sub-part)
        """
    def LoadedGraph(self) -> OCP.Interface.Interface_Graph: 
        """
        Same as above, but under the form of a Graph
        """
    def Model(self) -> OCP.Interface.Interface_InterfaceModel: 
        """
        Returns the Model with which this Iterator was created
        """
    def More(self) -> bool: 
        """
        Returns True if there are more sub-parts to iterate on Note : an empty sub-part is not taken in account by Iteration
        """
    def NbParts(self) -> int: 
        """
        Returns count of registered parts
        """
    def Next(self) -> None: 
        """
        Sets iteration to the next sub-part if there is not, IsSingle-Entities will raises an exception
        """
    def PartNum(self) -> int: 
        """
        Returns numero of part which currently receives entities (0 at load time)
        """
    def Reset(self) -> None: 
        """
        Erases data (parts, entities) : "me" becomes empty and in load status
        """
    def SetLoad(self) -> None: 
        """
        Sets SubPartIterator to get Entities (by GetFromEntity & GetFromIter) into load status, to be analysed later
        """
    def SetPartNum(self,num : int) -> None: 
        """
        Sets numero of receiving part to a new value Error if not in range (1-NbParts)
        """
    def Start(self) -> None: 
        """
        Sets iteration to its beginning; calls Evaluate
        """
    @overload
    def __init__(self,agraph : OCP.Interface.Interface_Graph,whole : bool) -> None: ...
    @overload
    def __init__(self,other : IFGraph_SubPartsIterator) -> None: ...
    pass
class IFGraph_Cumulate(OCP.Interface.Interface_GraphContent, OCP.Interface.Interface_EntityIterator):
    """
    this class evaluates effect of cumulated sub-parts : overlapping, forgotten entities Results are kept in a Graph, several question can be set Basic Iteration gives entities which are part of Cumulation
    """
    def AddItem(self,anentity : OCP.Standard.Standard_Transient) -> None: 
        """
        Adds to the iteration list a defined entity
        """
    def AddList(self,list : OCP.TColStd.TColStd_HSequenceOfTransient) -> None: 
        """
        Gets a list of entities and adds its to the iteration list
        """
    def Begin(self) -> None: 
        """
        Does the Evaluation before starting the iteration itself (in out)
        """
    def Content(self) -> OCP.TColStd.TColStd_HSequenceOfTransient: 
        """
        Returns the content of the Iterator, accessed through a Handle to be used by a frontal-engine logic Returns an empty Sequence if the Iterator is empty Calls Start if not yet done
        """
    def Destroy(self) -> None: 
        """
        Clears data of iteration
        """
    def Evaluate(self) -> None: 
        """
        Evaluates the result of cumulation
        """
    def Forgotten(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        returns entities which are not taken
        """
    def GetFromEntity(self,ent : OCP.Standard.Standard_Transient) -> None: 
        """
        adds an entity and its shared ones to the list
        """
    @overload
    def GetFromGraph(self,agraph : OCP.Interface.Interface_Graph) -> None: 
        """
        Gets all Entities designated by a Graph (once created), adds them to those already recorded

        Gets entities from a graph which have a specific Status value (one created), adds them to those already recorded
        """
    @overload
    def GetFromGraph(self,agraph : OCP.Interface.Interface_Graph,stat : int) -> None: ...
    def GetFromIter(self,iter : OCP.Interface.Interface_EntityIterator) -> None: 
        """
        adds a list of entities (as an iterator) as such, that is, without their shared entities (use AllShared to have them)
        """
    def GetOneItem(self,anentity : OCP.Standard.Standard_Transient) -> None: 
        """
        same as AddItem (kept for compatibility)
        """
    def HighestNbTimes(self) -> int: 
        """
        Returns the highest number of times recorded for every Entity (0 means empty, 1 means no overlap)
        """
    def More(self) -> bool: 
        """
        Says if there are other entities (vertices) to iterate the first time, calls Start
        """
    def NbEntities(self) -> int: 
        """
        Returns count of entities which will be iterated on Calls Start if not yet done
        """
    def NbTimes(self,ent : OCP.Standard.Standard_Transient) -> int: 
        """
        returns number of times an Entity has been counted (0 means forgotten, more than 1 means overlap, 1 is normal)
        """
    def NbTyped(self,type : OCP.Standard.Standard_Type) -> int: 
        """
        Returns count of entities of a given type (kind of)
        """
    def Next(self) -> None: 
        """
        Sets iteration to the next entity (vertex) to give
        """
    def Overlapped(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        returns entities which are taken several times
        """
    def PerCount(self,count : int=1) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns entities taken a given count of times (0 : same as Forgotten, 1 : same as no Overlap : default)
        """
    def ResetData(self) -> None: 
        """
        Allows to restart on a new data set
        """
    def Result(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns Result under the exact form of an EntityIterator : Can be used when EntityIterator itself is required (as a returned value for instance), without way for a sub-class
        """
    def SelectType(self,atype : OCP.Standard.Standard_Type,keep : bool) -> None: 
        """
        Selects entities with are Kind of a given type, keep only them (is keep is True) or reject only them (if keep is False)
        """
    def Start(self) -> None: 
        """
        Allows re-iteration (useless for the first iteration)
        """
    def Typed(self,type : OCP.Standard.Standard_Type) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns the list of entities of a given type (kind of)
        """
    def Value(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns the current Entity iterated, to be used by Interface tools
        """
    def __init__(self,agraph : OCP.Interface.Interface_Graph) -> None: ...
    pass
class IFGraph_Cycles(IFGraph_SubPartsIterator):
    """
    determines strong components in a graph which are Cycles
    """
    def AddPart(self) -> None: 
        """
        Adds an empty part and sets it to receive entities
        """
    def Entities(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns current sub-part, not as a "Value", but as an Iterator on Entities it contains Error : same as above (end of iteration)
        """
    def EntityPartNum(self,ent : OCP.Standard.Standard_Transient) -> int: 
        """
        Returns number of the sub-part in which an Entity has been set if it is not in a sub-part (or not loaded at all), Returns 0
        """
    def Evaluate(self) -> None: 
        """
        does the computation. Cycles are StrongComponants which are not Single
        """
    def FirstEntity(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns the first entity of current sub-part, that is for a Single one, the only one it contains Error : same as above (end of iteration)
        """
    def GetFromEntity(self,ent : OCP.Standard.Standard_Transient,shared : bool) -> None: 
        """
        Adds an Entity : into load status if in Load mode, to the current part if there is one. If shared is True, adds also its shared ones (shared at all levels)
        """
    def GetFromIter(self,iter : OCP.Interface.Interface_EntityIterator) -> None: 
        """
        Adds a list of Entities (into Load mode or to a Part), given as an Iterator
        """
    def GetParts(self,other : IFGraph_SubPartsIterator) -> None: 
        """
        Gets Parts from another SubPartsIterator (in addition to the ones already recorded) Error if both SubPartsIterators are not based on the same Model
        """
    def IsInPart(self,ent : OCP.Standard.Standard_Transient) -> bool: 
        """
        Returns True if an Entity is Present in a sub-part
        """
    def IsLoaded(self,ent : OCP.Standard.Standard_Transient) -> bool: 
        """
        Returns True if an Entity is loaded (either set into a sub-part or not)
        """
    def IsSingle(self) -> bool: 
        """
        Returns True if current sub-part is single (has only one Entity) Error if there is no sub-part to iterate now
        """
    def Loaded(self) -> OCP.Interface.Interface_GraphContent: 
        """
        Returns entities which where loaded (not set into a sub-part)
        """
    def LoadedGraph(self) -> OCP.Interface.Interface_Graph: 
        """
        Same as above, but under the form of a Graph
        """
    def Model(self) -> OCP.Interface.Interface_InterfaceModel: 
        """
        Returns the Model with which this Iterator was created
        """
    def More(self) -> bool: 
        """
        Returns True if there are more sub-parts to iterate on Note : an empty sub-part is not taken in account by Iteration
        """
    def NbParts(self) -> int: 
        """
        Returns count of registered parts
        """
    def Next(self) -> None: 
        """
        Sets iteration to the next sub-part if there is not, IsSingle-Entities will raises an exception
        """
    def PartNum(self) -> int: 
        """
        Returns numero of part which currently receives entities (0 at load time)
        """
    def Reset(self) -> None: 
        """
        Erases data (parts, entities) : "me" becomes empty and in load status
        """
    def SetLoad(self) -> None: 
        """
        Sets SubPartIterator to get Entities (by GetFromEntity & GetFromIter) into load status, to be analysed later
        """
    def SetPartNum(self,num : int) -> None: 
        """
        Sets numero of receiving part to a new value Error if not in range (1-NbParts)
        """
    def Start(self) -> None: 
        """
        Sets iteration to its beginning; calls Evaluate
        """
    @overload
    def __init__(self,agraph : OCP.Interface.Interface_Graph,whole : bool) -> None: ...
    @overload
    def __init__(self,subparts : IFGraph_StrongComponants) -> None: ...
    pass
class IFGraph_ExternalSources(OCP.Interface.Interface_GraphContent, OCP.Interface.Interface_EntityIterator):
    """
    this class gives entities which are Source of entities of a sub-part, but are not contained by this sub-part
    """
    def AddItem(self,anentity : OCP.Standard.Standard_Transient) -> None: 
        """
        Adds to the iteration list a defined entity
        """
    def AddList(self,list : OCP.TColStd.TColStd_HSequenceOfTransient) -> None: 
        """
        Gets a list of entities and adds its to the iteration list
        """
    def Begin(self) -> None: 
        """
        Does the Evaluation before starting the iteration itself (in out)
        """
    def Content(self) -> OCP.TColStd.TColStd_HSequenceOfTransient: 
        """
        Returns the content of the Iterator, accessed through a Handle to be used by a frontal-engine logic Returns an empty Sequence if the Iterator is empty Calls Start if not yet done
        """
    def Destroy(self) -> None: 
        """
        Clears data of iteration
        """
    def Evaluate(self) -> None: 
        """
        Evaluates external sources of a set of entities
        """
    def GetFromEntity(self,ent : OCP.Standard.Standard_Transient) -> None: 
        """
        adds an entity and its shared ones to the list
        """
    @overload
    def GetFromGraph(self,agraph : OCP.Interface.Interface_Graph) -> None: 
        """
        Gets all Entities designated by a Graph (once created), adds them to those already recorded

        Gets entities from a graph which have a specific Status value (one created), adds them to those already recorded
        """
    @overload
    def GetFromGraph(self,agraph : OCP.Interface.Interface_Graph,stat : int) -> None: ...
    def GetFromIter(self,iter : OCP.Interface.Interface_EntityIterator) -> None: 
        """
        adds a list of entities (as an iterator) with shared ones
        """
    def GetOneItem(self,anentity : OCP.Standard.Standard_Transient) -> None: 
        """
        same as AddItem (kept for compatibility)
        """
    def IsEmpty(self) -> bool: 
        """
        Returns True if no External Source are found It means that we have a "root" set (performs an Evaluation as necessary)
        """
    def More(self) -> bool: 
        """
        Says if there are other entities (vertices) to iterate the first time, calls Start
        """
    def NbEntities(self) -> int: 
        """
        Returns count of entities which will be iterated on Calls Start if not yet done
        """
    def NbTyped(self,type : OCP.Standard.Standard_Type) -> int: 
        """
        Returns count of entities of a given type (kind of)
        """
    def Next(self) -> None: 
        """
        Sets iteration to the next entity (vertex) to give
        """
    def ResetData(self) -> None: 
        """
        Allows to restart on a new data set
        """
    def Result(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns Result under the exact form of an EntityIterator : Can be used when EntityIterator itself is required (as a returned value for instance), without way for a sub-class
        """
    def SelectType(self,atype : OCP.Standard.Standard_Type,keep : bool) -> None: 
        """
        Selects entities with are Kind of a given type, keep only them (is keep is True) or reject only them (if keep is False)
        """
    def Start(self) -> None: 
        """
        Allows re-iteration (useless for the first iteration)
        """
    def Typed(self,type : OCP.Standard.Standard_Type) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns the list of entities of a given type (kind of)
        """
    def Value(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns the current Entity iterated, to be used by Interface tools
        """
    def __init__(self,agraph : OCP.Interface.Interface_Graph) -> None: ...
    pass
class IFGraph_StrongComponants(IFGraph_SubPartsIterator):
    """
    determines strong components of a graph, that is isolated entities (single components) or loops
    """
    def AddPart(self) -> None: 
        """
        Adds an empty part and sets it to receive entities
        """
    def Entities(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns current sub-part, not as a "Value", but as an Iterator on Entities it contains Error : same as above (end of iteration)
        """
    def EntityPartNum(self,ent : OCP.Standard.Standard_Transient) -> int: 
        """
        Returns number of the sub-part in which an Entity has been set if it is not in a sub-part (or not loaded at all), Returns 0
        """
    def Evaluate(self) -> None: 
        """
        does the computation
        """
    def FirstEntity(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns the first entity of current sub-part, that is for a Single one, the only one it contains Error : same as above (end of iteration)
        """
    def GetFromEntity(self,ent : OCP.Standard.Standard_Transient,shared : bool) -> None: 
        """
        Adds an Entity : into load status if in Load mode, to the current part if there is one. If shared is True, adds also its shared ones (shared at all levels)
        """
    def GetFromIter(self,iter : OCP.Interface.Interface_EntityIterator) -> None: 
        """
        Adds a list of Entities (into Load mode or to a Part), given as an Iterator
        """
    def GetParts(self,other : IFGraph_SubPartsIterator) -> None: 
        """
        Gets Parts from another SubPartsIterator (in addition to the ones already recorded) Error if both SubPartsIterators are not based on the same Model
        """
    def IsInPart(self,ent : OCP.Standard.Standard_Transient) -> bool: 
        """
        Returns True if an Entity is Present in a sub-part
        """
    def IsLoaded(self,ent : OCP.Standard.Standard_Transient) -> bool: 
        """
        Returns True if an Entity is loaded (either set into a sub-part or not)
        """
    def IsSingle(self) -> bool: 
        """
        Returns True if current sub-part is single (has only one Entity) Error if there is no sub-part to iterate now
        """
    def Loaded(self) -> OCP.Interface.Interface_GraphContent: 
        """
        Returns entities which where loaded (not set into a sub-part)
        """
    def LoadedGraph(self) -> OCP.Interface.Interface_Graph: 
        """
        Same as above, but under the form of a Graph
        """
    def Model(self) -> OCP.Interface.Interface_InterfaceModel: 
        """
        Returns the Model with which this Iterator was created
        """
    def More(self) -> bool: 
        """
        Returns True if there are more sub-parts to iterate on Note : an empty sub-part is not taken in account by Iteration
        """
    def NbParts(self) -> int: 
        """
        Returns count of registered parts
        """
    def Next(self) -> None: 
        """
        Sets iteration to the next sub-part if there is not, IsSingle-Entities will raises an exception
        """
    def PartNum(self) -> int: 
        """
        Returns numero of part which currently receives entities (0 at load time)
        """
    def Reset(self) -> None: 
        """
        Erases data (parts, entities) : "me" becomes empty and in load status
        """
    def SetLoad(self) -> None: 
        """
        Sets SubPartIterator to get Entities (by GetFromEntity & GetFromIter) into load status, to be analysed later
        """
    def SetPartNum(self,num : int) -> None: 
        """
        Sets numero of receiving part to a new value Error if not in range (1-NbParts)
        """
    def Start(self) -> None: 
        """
        Sets iteration to its beginning; calls Evaluate
        """
    def __init__(self,agraph : OCP.Interface.Interface_Graph,whole : bool) -> None: ...
    pass
class IFGraph_SCRoots(IFGraph_StrongComponants, IFGraph_SubPartsIterator):
    """
    determines strong components in a graph which are Roots
    """
    def AddPart(self) -> None: 
        """
        Adds an empty part and sets it to receive entities
        """
    def Entities(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns current sub-part, not as a "Value", but as an Iterator on Entities it contains Error : same as above (end of iteration)
        """
    def EntityPartNum(self,ent : OCP.Standard.Standard_Transient) -> int: 
        """
        Returns number of the sub-part in which an Entity has been set if it is not in a sub-part (or not loaded at all), Returns 0
        """
    def Evaluate(self) -> None: 
        """
        does the computation
        """
    def FirstEntity(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns the first entity of current sub-part, that is for a Single one, the only one it contains Error : same as above (end of iteration)
        """
    def GetFromEntity(self,ent : OCP.Standard.Standard_Transient,shared : bool) -> None: 
        """
        Adds an Entity : into load status if in Load mode, to the current part if there is one. If shared is True, adds also its shared ones (shared at all levels)
        """
    def GetFromIter(self,iter : OCP.Interface.Interface_EntityIterator) -> None: 
        """
        Adds a list of Entities (into Load mode or to a Part), given as an Iterator
        """
    def GetParts(self,other : IFGraph_SubPartsIterator) -> None: 
        """
        Gets Parts from another SubPartsIterator (in addition to the ones already recorded) Error if both SubPartsIterators are not based on the same Model
        """
    def IsInPart(self,ent : OCP.Standard.Standard_Transient) -> bool: 
        """
        Returns True if an Entity is Present in a sub-part
        """
    def IsLoaded(self,ent : OCP.Standard.Standard_Transient) -> bool: 
        """
        Returns True if an Entity is loaded (either set into a sub-part or not)
        """
    def IsSingle(self) -> bool: 
        """
        Returns True if current sub-part is single (has only one Entity) Error if there is no sub-part to iterate now
        """
    def Loaded(self) -> OCP.Interface.Interface_GraphContent: 
        """
        Returns entities which where loaded (not set into a sub-part)
        """
    def LoadedGraph(self) -> OCP.Interface.Interface_Graph: 
        """
        Same as above, but under the form of a Graph
        """
    def Model(self) -> OCP.Interface.Interface_InterfaceModel: 
        """
        Returns the Model with which this Iterator was created
        """
    def More(self) -> bool: 
        """
        Returns True if there are more sub-parts to iterate on Note : an empty sub-part is not taken in account by Iteration
        """
    def NbParts(self) -> int: 
        """
        Returns count of registered parts
        """
    def Next(self) -> None: 
        """
        Sets iteration to the next sub-part if there is not, IsSingle-Entities will raises an exception
        """
    def PartNum(self) -> int: 
        """
        Returns numero of part which currently receives entities (0 at load time)
        """
    def Reset(self) -> None: 
        """
        Erases data (parts, entities) : "me" becomes empty and in load status
        """
    def SetLoad(self) -> None: 
        """
        Sets SubPartIterator to get Entities (by GetFromEntity & GetFromIter) into load status, to be analysed later
        """
    def SetPartNum(self,num : int) -> None: 
        """
        Sets numero of receiving part to a new value Error if not in range (1-NbParts)
        """
    def Start(self) -> None: 
        """
        Sets iteration to its beginning; calls Evaluate
        """
    @overload
    def __init__(self,agraph : OCP.Interface.Interface_Graph,whole : bool) -> None: ...
    @overload
    def __init__(self,subparts : IFGraph_StrongComponants) -> None: ...
    pass
class IFGraph_ConnectedComponants(IFGraph_SubPartsIterator):
    """
    determines Connected Components in a Graph. They define disjoined sets of Entities.
    """
    def AddPart(self) -> None: 
        """
        Adds an empty part and sets it to receive entities
        """
    def Entities(self) -> OCP.Interface.Interface_EntityIterator: 
        """
        Returns current sub-part, not as a "Value", but as an Iterator on Entities it contains Error : same as above (end of iteration)
        """
    def EntityPartNum(self,ent : OCP.Standard.Standard_Transient) -> int: 
        """
        Returns number of the sub-part in which an Entity has been set if it is not in a sub-part (or not loaded at all), Returns 0
        """
    def Evaluate(self) -> None: 
        """
        does the computation
        """
    def FirstEntity(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns the first entity of current sub-part, that is for a Single one, the only one it contains Error : same as above (end of iteration)
        """
    def GetFromEntity(self,ent : OCP.Standard.Standard_Transient,shared : bool) -> None: 
        """
        Adds an Entity : into load status if in Load mode, to the current part if there is one. If shared is True, adds also its shared ones (shared at all levels)
        """
    def GetFromIter(self,iter : OCP.Interface.Interface_EntityIterator) -> None: 
        """
        Adds a list of Entities (into Load mode or to a Part), given as an Iterator
        """
    def GetParts(self,other : IFGraph_SubPartsIterator) -> None: 
        """
        Gets Parts from another SubPartsIterator (in addition to the ones already recorded) Error if both SubPartsIterators are not based on the same Model
        """
    def IsInPart(self,ent : OCP.Standard.Standard_Transient) -> bool: 
        """
        Returns True if an Entity is Present in a sub-part
        """
    def IsLoaded(self,ent : OCP.Standard.Standard_Transient) -> bool: 
        """
        Returns True if an Entity is loaded (either set into a sub-part or not)
        """
    def IsSingle(self) -> bool: 
        """
        Returns True if current sub-part is single (has only one Entity) Error if there is no sub-part to iterate now
        """
    def Loaded(self) -> OCP.Interface.Interface_GraphContent: 
        """
        Returns entities which where loaded (not set into a sub-part)
        """
    def LoadedGraph(self) -> OCP.Interface.Interface_Graph: 
        """
        Same as above, but under the form of a Graph
        """
    def Model(self) -> OCP.Interface.Interface_InterfaceModel: 
        """
        Returns the Model with which this Iterator was created
        """
    def More(self) -> bool: 
        """
        Returns True if there are more sub-parts to iterate on Note : an empty sub-part is not taken in account by Iteration
        """
    def NbParts(self) -> int: 
        """
        Returns count of registered parts
        """
    def Next(self) -> None: 
        """
        Sets iteration to the next sub-part if there is not, IsSingle-Entities will raises an exception
        """
    def PartNum(self) -> int: 
        """
        Returns numero of part which currently receives entities (0 at load time)
        """
    def Reset(self) -> None: 
        """
        Erases data (parts, entities) : "me" becomes empty and in load status
        """
    def SetLoad(self) -> None: 
        """
        Sets SubPartIterator to get Entities (by GetFromEntity & GetFromIter) into load status, to be analysed later
        """
    def SetPartNum(self,num : int) -> None: 
        """
        Sets numero of receiving part to a new value Error if not in range (1-NbParts)
        """
    def Start(self) -> None: 
        """
        Sets iteration to its beginning; calls Evaluate
        """
    def __init__(self,agraph : OCP.Interface.Interface_Graph,whole : bool) -> None: ...
    pass



import OCP.Xw
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.Aspect
import io
import OCP.Quantity
import OCP.TCollection
import OCP.Standard
import OCP.Graphic3d
__all__  = [
"Xw_Window",
"__GLXFBConfigRec"
]
class Xw_Window(OCP.Aspect.Aspect_Window, OCP.Standard.Standard_Transient):
    """
    This class defines XLib window intended for creation of OpenGL context.This class defines XLib window intended for creation of OpenGL context.
    """
    def Background(self) -> OCP.Aspect.Aspect_Background: 
        """
        Returns the window background.
        """
    def BackgroundFillMethod(self) -> OCP.Aspect.Aspect_FillMethod: 
        """
        Returns the current image background fill mode.
        """
    def ConvertPointFromBacking(self,thePnt : OCP.Graphic3d.Graphic3d_Vec2d) -> OCP.Graphic3d.Graphic3d_Vec2d: 
        """
        Convert point from backing store units to logical units.
        """
    def ConvertPointToBacking(self,thePnt : OCP.Graphic3d.Graphic3d_Vec2d) -> OCP.Graphic3d.Graphic3d_Vec2d: 
        """
        Convert point from logical units into backing store units.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DevicePixelRatio(self) -> float: 
        """
        Return device pixel ratio (logical to backing store scale factor).
        """
    def Dimensions(self) -> OCP.Graphic3d.Graphic3d_Vec2i: 
        """
        Returns window dimensions.
        """
    def DisplayConnection(self) -> OCP.Aspect.Aspect_DisplayConnection: 
        """
        Returns connection to Display or NULL.
        """
    def DoMapping(self) -> bool: 
        """
        Apply the mapping change to the window <me>
        """
    def DoResize(self) -> OCP.Aspect.Aspect_TypeOfResize: 
        """
        Applies the resizing to the window <me>
        """
    def DumpJson(self,theOStream : io.BytesIO,theDepth : int=-1) -> None: 
        """
        Dumps the content of me into the stream
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GradientBackground(self) -> OCP.Aspect.Aspect_GradientBackground: 
        """
        Returns the window gradient background.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def InvalidateContent(self,theDisp : OCP.Aspect.Aspect_DisplayConnection) -> None: 
        """
        Invalidate entire window content through generation of Expose event. This method does not aggregate multiple calls into single event - dedicated event will be sent on each call. When NULL display connection is specified, the connection specified on window creation will be used. Sending exposure messages from non-window thread would require dedicated display connection opened specifically for this working thread to avoid race conditions, since Xlib display connection is not thread-safe by default.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsMapped(self) -> bool: 
        """
        Returns True if the window <me> is opened
        """
    def IsVirtual(self) -> bool: 
        """
        Returns True if the window <me> is virtual
        """
    def Map(self) -> None: 
        """
        Opens the window <me>
        """
    def NativeFBConfig(self) -> __GLXFBConfigRec: 
        """
        Returns native Window FB config (GLXFBConfig on Xlib)
        """
    def NativeHandle(self) -> int: 
        """
        Returns native Window handle
        """
    def NativeParentHandle(self) -> int: 
        """
        Returns parent of native Window handle
        """
    def Position(self) -> tuple[int, int, int, int]: 
        """
        Returns The Window POSITION in PIXEL
        """
    def ProcessMessage(self,theListener : OCP.Aspect.Aspect_WindowInputListener,theMsg : _XEvent) -> bool: 
        """
        Process a single window message.
        """
    def Ratio(self) -> float: 
        """
        Returns The Window RATIO equal to the physical WIDTH/HEIGHT dimensions
        """
    @overload
    def SetBackground(self,theBack : OCP.Aspect.Aspect_Background) -> None: 
        """
        Modifies the window background.

        Modifies the window background.

        Modifies the window gradient background.

        Modifies the window gradient background.
        """
    @overload
    def SetBackground(self,theColor : OCP.Quantity.Quantity_Color) -> None: ...
    @overload
    def SetBackground(self,theBackground : OCP.Aspect.Aspect_GradientBackground) -> None: ...
    @overload
    def SetBackground(self,theFirstColor : OCP.Quantity.Quantity_Color,theSecondColor : OCP.Quantity.Quantity_Color,theFillMethod : OCP.Aspect.Aspect_GradientFillMethod) -> None: ...
    def SetTitle(self,theTitle : OCP.TCollection.TCollection_AsciiString) -> None: 
        """
        Sets window title.
        """
    def SetVirtual(self,theVirtual : bool) -> None: 
        """
        Setup the virtual state
        """
    def Size(self) -> tuple[int, int]: 
        """
        Returns The Window SIZE in PIXEL
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TopLeft(self) -> OCP.Graphic3d.Graphic3d_Vec2i: 
        """
        Returns window top-left corner.
        """
    def Unmap(self) -> None: 
        """
        Closes the window <me>
        """
    @staticmethod
    def VirtualKeyFromNative_s(theKey : int) -> int: 
        """
        Convert X11 virtual key (KeySym) into Aspect_VKey.
        """
    def XWindow(self) -> int: 
        """
        Returns native Window handle
        """
    @overload
    def __init__(self,theXDisplay : OCP.Aspect.Aspect_DisplayConnection,theTitle : str,thePxLeft : int,thePxTop : int,thePxWidth : int,thePxHeight : int) -> None: ...
    @overload
    def __init__(self,theXDisplay : OCP.Aspect.Aspect_DisplayConnection,theXWin : int,theFBConfig : __GLXFBConfigRec=None) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class __GLXFBConfigRec():
    pass



import OCP.Plugin
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.Standard
__all__  = [
"Plugin",
"Plugin_Failure"
]
class Plugin():
    @staticmethod
    def Load_s(aGUID : OCP.Standard.Standard_GUID,theVerbose : bool=True) -> OCP.Standard.Standard_Transient: ...
    def __init__(self) -> None: ...
    pass
class Plugin_Failure(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Plugin', '__weakref__': <attribute '__weakref__' of 'Plugin_Failure' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Plugin_Failure' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass



import OCP.Standard
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import io
import Standard
import OCP.TColStd
__all__  = [
"Standard",
"Standard_AbortiveTransaction",
"Standard_ArrayStreamBuffer",
"Standard_CLocaleSentry",
"Standard_CStringHasher",
"Standard_Condition",
"Standard_ConstructionError",
"Standard_DimensionError",
"Standard_DimensionMismatch",
"Standard_DivideByZero",
"Standard_DomainError",
"Standard_Dump",
"Standard_DumpValue",
"Standard_ErrorHandler",
"Standard_Failure",
"Standard_GUID",
"Standard_HandlerStatus",
"Standard_ImmutableObject",
"Standard_JsonKey",
"Standard_LicenseError",
"Standard_LicenseNotFound",
"Standard_MMgrRoot",
"Standard_MMgrOpt",
"Standard_MultiplyDefined",
"Standard_Mutex",
"Standard_NegativeValue",
"Standard_NoMoreObject",
"Standard_NoSuchObject",
"Standard_NotImplemented",
"Standard_NullObject",
"Standard_NullValue",
"Standard_NumericError",
"Standard_OutOfMemory",
"Standard_OutOfRange",
"Standard_Overflow",
"Standard_Transient",
"Standard_ProgramError",
"Standard_RangeError",
"Standard_ReadBuffer",
"Standard_ReadLineBuffer",
"Standard_Static_Assert_true",
"Standard_Persistent",
"Standard_Type",
"Standard_TypeMismatch",
"Standard_UUID",
"Standard_Underflow",
"ACos",
"ACosApprox",
"ACosh",
"ASin",
"ASinh",
"ATan",
"ATan2",
"ATanh",
"Abs",
"Ceiling",
"Cos",
"Cosh",
"Epsilon",
"Exp",
"Floor",
"IntToReal",
"IntegerFirst",
"IntegerLast",
"IntegerPart",
"IntegerSize",
"IsAlphabetic",
"IsAlphanumeric",
"IsAnAscii",
"IsControl",
"IsDigit",
"IsEqual",
"IsEven",
"IsGraphic",
"IsLowerCase",
"IsOdd",
"IsPrintable",
"IsPunctuation",
"IsSpace",
"IsUpperCase",
"IsXDigit",
"Log",
"Log10",
"LowerCase",
"Max",
"Min",
"Modulus",
"NextAfter",
"Pow",
"RealDigits",
"RealEpsilon",
"RealFirst",
"RealFirst10Exp",
"RealLast",
"RealLast10Exp",
"RealMantissa",
"RealPart",
"RealRadix",
"RealSize",
"RealSmall",
"RealToInt",
"RealToShortReal",
"Round",
"ShortRealDigits",
"ShortRealEpsilon",
"ShortRealFirst",
"ShortRealFirst10Exp",
"ShortRealLast",
"ShortRealLast10Exp",
"ShortRealMantissa",
"ShortRealRadix",
"ShortRealSize",
"ShortRealSmall",
"Sign",
"Sin",
"Sinh",
"Sqrt",
"Square",
"Standard_ASSERT_DO_NOTHING",
"Standard_Atomic_CompareAndSwap",
"Standard_Atomic_Decrement",
"Standard_Atomic_Increment",
"Tan",
"Tanh",
"ToCharacter",
"ToExtCharacter",
"UpperCase",
"Standard_HandlerJumped",
"Standard_HandlerProcessed",
"Standard_HandlerVoid",
"Standard_JsonKey_CloseChild",
"Standard_JsonKey_CloseContainer",
"Standard_JsonKey_None",
"Standard_JsonKey_OpenChild",
"Standard_JsonKey_OpenContainer",
"Standard_JsonKey_Quote",
"Standard_JsonKey_SeparatorKeyToValue",
"Standard_JsonKey_SeparatorValueToValue"
]
class Standard():
    """
    The package Standard provides global memory allocator and other basic services used by other OCCT components.
    """
    class AllocatorType_e():
        """
        Enumiration of possible allocator types

        Members:

          NATIVE

          OPT

          TBB

          JEMALLOC
        """
        def __eq__(self,other : object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __init__(self,value : int) -> None: ...
        def __int__(self) -> int: ...
        def __ne__(self,other : object) -> bool: ...
        def __repr__(self) -> str: ...
        def __setstate__(self,state : int) -> None: ...
        def __str__(self) -> str: ...
        @property
        def name(self) -> None:
            """
            :type: None
            """
        @property
        def value(self) -> int:
            """
            :type: int
            """
        JEMALLOC: OCP.Standard.AllocatorType_e # value = <AllocatorType_e.JEMALLOC: 3>
        NATIVE: OCP.Standard.AllocatorType_e # value = <AllocatorType_e.NATIVE: 0>
        OPT: OCP.Standard.AllocatorType_e # value = <AllocatorType_e.OPT: 1>
        TBB: OCP.Standard.AllocatorType_e # value = <AllocatorType_e.TBB: 2>
        __entries: dict # value = {'NATIVE': (<AllocatorType_e.NATIVE: 0>, None), 'OPT': (<AllocatorType_e.OPT: 1>, None), 'TBB': (<AllocatorType_e.TBB: 2>, None), 'JEMALLOC': (<AllocatorType_e.JEMALLOC: 3>, None)}
        __members__: dict # value = {'NATIVE': <AllocatorType_e.NATIVE: 0>, 'OPT': <AllocatorType_e.OPT: 1>, 'TBB': <AllocatorType_e.TBB: 2>, 'JEMALLOC': <AllocatorType_e.JEMALLOC: 3>}
        pass
    @staticmethod
    def AllocateAligned_s(theSize : int,theAlign : int) -> capsule: 
        """
        Allocates aligned memory blocks. Should be used with CPU instructions which require specific alignment. For example: SSE requires 16 bytes, AVX requires 32 bytes.
        """
    @staticmethod
    def AllocateOptimal_s(theSize : int) -> capsule: 
        """
        Allocates memory blocks theSize - bytes to allocate
        """
    @staticmethod
    def Allocate_s(theSize : int) -> capsule: 
        """
        Allocates memory blocks theSize - bytes to allocate
        """
    @staticmethod
    def FreeAligned_s(thePtrAligned : capsule) -> None: 
        """
        Deallocates memory blocks
        """
    @staticmethod
    def Free_s(thePtr : capsule) -> None: 
        """
        Deallocates memory blocks
        """
    @staticmethod
    def GetAllocatorType_s() -> Standard.AllocatorType_e: 
        """
        Returns default allocator type
        """
    @staticmethod
    def Purge_s() -> int: 
        """
        Deallocates the storage retained on the free list and clears the list. Returns non-zero if some memory has been actually freed.
        """
    @staticmethod
    def Reallocate_s(theStorage : capsule,theNewSize : int) -> capsule: 
        """
        Reallocates memory blocks theStorage - previously allocated memory block theNewSize - new size in bytes
        """
    @staticmethod
    def StackTrace_s(theBuffer : str,theBufferSize : int,theNbTraces : int,theContext : capsule=None,theNbTopSkip : int=0) -> bool: 
        """
        Appends backtrace to a message buffer. Stack information might be incomplete in case of stripped binaries. Implementation details: - Not implemented for Android, iOS, QNX and UWP platforms. - On non-Windows platform, this function is a wrapper to backtrace() system call. - On Windows (Win32) platform, the function loads DbgHelp.dll dynamically, and no stack will be provided if this or companion libraries (SymSrv.dll, SrcSrv.dll, etc.) will not be found; .pdb symbols should be provided on Windows platform to retrieve a meaningful stack; only x86_64 CPU architecture is currently implemented.
        """
    def __init__(self) -> None: ...
    JEMALLOC: OCP.Standard.AllocatorType_e # value = <AllocatorType_e.JEMALLOC: 3>
    NATIVE: OCP.Standard.AllocatorType_e # value = <AllocatorType_e.NATIVE: 0>
    OPT: OCP.Standard.AllocatorType_e # value = <AllocatorType_e.OPT: 1>
    TBB: OCP.Standard.AllocatorType_e # value = <AllocatorType_e.TBB: 2>
    pass
class Standard_AbortiveTransaction(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_AbortiveTransaction' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_AbortiveTransaction' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_ArrayStreamBuffer():
    """
    Custom buffer object implementing STL interface std::streambuf for streamed reading from allocated memory block. Implements minimal sub-set of methods for passing buffer to std::istream, including seek support.
    """
    def Init(self,theBegin : str,theSize : int) -> None: 
        """
        (Re)-initialize the stream. Passed pointer is stored as is (memory is NOT copied nor released with destructor).
        """
    def __init__(self,theBegin : str,theSize : int) -> None: ...
    def xsgetn(self,thePtr : str,theCount : int) -> int: 
        """
        Read a bunch of bytes at once.
        """
    pass
class Standard_CLocaleSentry():
    """
    This class intended to temporary switch C locale and logically equivalent to setlocale(LC_ALL, "C"). It is intended to format text regardless of user locale settings (for import/export functionality). Thus following calls to sprintf, atoi and other functions will use "C" locale. Destructor of this class will return original locale.
    """
    def __init__(self) -> None: ...
    pass
class Standard_CStringHasher():
    @overload
    def __call__(self,theString : str) -> int: ...
    @overload
    def __call__(self,theString1 : str,theString2 : str) -> bool: ...
    def __init__(self) -> None: ...
    pass
class Standard_Condition():
    """
    This is boolean flag intended for communication between threads. One thread sets this flag to TRUE to indicate some event happened and another thread either waits this event or checks periodically its state to perform job.
    """
    def Check(self) -> bool: 
        """
        Do not wait for signal - just test it state.
        """
    def CheckReset(self) -> bool: 
        """
        Method perform two steps at-once - reset the event object and returns true if it was in signaling state.
        """
    def Reset(self) -> None: 
        """
        Reset event (unset signaling state)
        """
    def Set(self) -> None: 
        """
        Set event into signaling state.
        """
    @overload
    def Wait(self) -> None: 
        """
        Wait for Event (infinity).

        Wait for signal requested time.
        """
    @overload
    def Wait(self,theTimeMilliseconds : int) -> bool: ...
    def __init__(self,theIsSet : bool) -> None: ...
    pass
class Standard_ConstructionError(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_ConstructionError' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_ConstructionError' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_DimensionError(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_DimensionError' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_DimensionError' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_DimensionMismatch(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_DimensionMismatch' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_DimensionMismatch' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_DivideByZero(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_DivideByZero' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_DivideByZero' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_DomainError(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_DomainError' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_DomainError' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_Dump():
    """
    This interface has some tool methods for stream (in JSON format) processing.
    """
    @staticmethod
    def AddValuesSeparator_s(theOStream : io.BytesIO) -> None: ...
    @staticmethod
    def DumpFieldToName_s(theField : OCP.TCollection.TCollection_AsciiString) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Convert field name into dump text value, removes "&" and "my" prefixes An example, for field myValue, theName is Value, for &myCLass, the name is Class
        """
    @staticmethod
    def DumpKeyToClass_s(theOStream : io.BytesIO,theKey : OCP.TCollection.TCollection_AsciiString,theField : OCP.TCollection.TCollection_AsciiString) -> None: 
        """
        Append into output value: "Name": { Field }
        """
    @staticmethod
    def FormatJson_s(theStream : Any,theIndent : int=3) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Converts stream value to string value. Improves the text presentation with the following cases: - for '{' append after '' and indent to the next value, increment current indent value - for '}' append '' and current indent before it, decrement indent value - for ',' append after '' and indent to the next value. If the current symbol is in massive container [], do nothing Covers result with opened and closed brackets on the top level, if it has no symbols there.
        """
    @staticmethod
    @overload
    def GetPointerInfo_s(thePointer : Standard_Transient,isShortInfo : bool=True) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Convert handle pointer to address of the pointer. If the handle is NULL, the result is an empty string.

        Convert pointer to address of the pointer. If the handle is NULL, the result is an empty string.
        """
    @staticmethod
    @overload
    def GetPointerInfo_s(thePointer : capsule,isShortInfo : bool=True) -> OCP.TCollection.TCollection_AsciiString: ...
    @staticmethod
    def GetPointerPrefix_s() -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns default prefix added for each pointer info string if short presentation of pointer used
        """
    @staticmethod
    def HasChildKey_s(theSourceValue : OCP.TCollection.TCollection_AsciiString) -> bool: 
        """
        Returns true if the value has bracket key
        """
    @staticmethod
    def HierarchicalValueIndices_s(theValues : OCP.TColStd.TColStd_IndexedDataMapOfStringString) -> OCP.TColStd.TColStd_ListOfInteger: 
        """
        Returns container of indices in values, that has hierarchical value
        """
    @staticmethod
    def InitValue_s(theStreamStr : OCP.TCollection.TCollection_AsciiString,theStreamPos : int,theValue : OCP.TCollection.TCollection_AsciiString) -> bool: 
        """
        Returns real value
        """
    @staticmethod
    def JsonKeyLength_s(theKey : Standard_JsonKey) -> int: 
        """
        Returns length value for enum type
        """
    @staticmethod
    def JsonKeyToString_s(theKey : Standard_JsonKey) -> str: 
        """
        Returns key value for enum type
        """
    @staticmethod
    def ProcessFieldName_s(theStreamStr : OCP.TCollection.TCollection_AsciiString,theName : OCP.TCollection.TCollection_AsciiString,theStreamPos : int) -> bool: 
        """
        Check whether the field name is equal to the name in the stream at position
        """
    @staticmethod
    def ProcessStreamName_s(theStreamStr : OCP.TCollection.TCollection_AsciiString,theName : OCP.TCollection.TCollection_AsciiString,theStreamPos : int) -> bool: 
        """
        Check whether the parameter name is equal to the name in the stream at position
        """
    @staticmethod
    def SplitJson_s(theStreamStr : OCP.TCollection.TCollection_AsciiString,theKeyToValues : Any) -> bool: 
        """
        Converts stream into map of values.
        """
    @staticmethod
    def Text_s(theStream : Any) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Converts stream value to string value. The result is original stream value.
        """
    def __init__(self) -> None: ...
    pass
class Standard_DumpValue():
    """
    Type for storing a dump value with the stream position
    """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theValue : OCP.TCollection.TCollection_AsciiString,theStartPos : int) -> None: ...
    @property
    def myStartPosition(self) -> int:
        """
        :type: int
        """
    @myStartPosition.setter
    def myStartPosition(self, arg0: int) -> None:
        pass
    @property
    def myValue(self) -> OCP.TCollection.TCollection_AsciiString:
        """
        :type: OCP.TCollection.TCollection_AsciiString
        """
    @myValue.setter
    def myValue(self, arg0: OCP.TCollection.TCollection_AsciiString) -> None:
        pass
    pass
class Standard_ErrorHandler():
    """
    Class implementing mechanics of conversion of signals to exceptions.
    """
    def Catches(self,aType : Standard_Type) -> bool: 
        """
        Returns "True" if the caught exception has the same type or inherits from "aType"
        """
    def Destroy(self) -> None: 
        """
        Unlinks and checks if there is a raised exception.
        """
    def Error(self) -> Standard_Failure: 
        """
        Returns the current Error.
        """
    @staticmethod
    def IsInTryBlock_s() -> bool: 
        """
        Test if the code is currently running in a try block
        """
    @staticmethod
    def LastCaughtError_s() -> Standard_Failure: 
        """
        Returns the caught exception.
        """
    def Unlink(self) -> None: 
        """
        Removes handler from the handlers list
        """
    def __init__(self) -> None: ...
    pass
class Standard_Failure(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_Failure' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_Failure' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_GUID():
    @overload
    def Assign(self,uid : Standard_GUID) -> None: ...
    @overload
    def Assign(self,uid : Standard_UUID) -> None: ...
    @staticmethod
    def CheckGUIDFormat_s(aGuid : str) -> bool: 
        """
        Check the format of a GUID string. It checks the size, the position of the '-' and the correct size of fields.
        """
    def IsNotSame(self,uid : Standard_GUID) -> bool: ...
    def IsSame(self,uid : Standard_GUID) -> bool: ...
    def ShallowDump(self,aStream : io.BytesIO) -> None: 
        """
        Display the GUID with the following format:
        """
    def ToCString(self,aStrGuid : str) -> None: 
        """
        translate the GUID into ascii string the aStrGuid is allocated by user. the guid have the following format:
        """
    def ToExtString(self,aStrGuid : str) -> None: 
        """
        translate the GUID into unicode string the aStrGuid is allocated by user. the guid have the following format:
        """
    def ToUUID(self) -> Standard_UUID: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,aGuid : str) -> None: ...
    @overload
    def __init__(self,a32b : int,a16b1 : str,a16b2 : str,a16b3 : str,a8b1 : int,a8b2 : int,a8b3 : int,a8b4 : int,a8b5 : int,a8b6 : int) -> None: ...
    @overload
    def __init__(self,aGuid : Standard_UUID) -> None: ...
    @overload
    def __init__(self,aGuid : Standard_GUID) -> None: ...
    pass
class Standard_HandlerStatus():
    """
    Members:

      Standard_HandlerVoid

      Standard_HandlerJumped

      Standard_HandlerProcessed
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    Standard_HandlerJumped: OCP.Standard.Standard_HandlerStatus # value = <Standard_HandlerStatus.Standard_HandlerJumped: 1>
    Standard_HandlerProcessed: OCP.Standard.Standard_HandlerStatus # value = <Standard_HandlerStatus.Standard_HandlerProcessed: 2>
    Standard_HandlerVoid: OCP.Standard.Standard_HandlerStatus # value = <Standard_HandlerStatus.Standard_HandlerVoid: 0>
    __entries: dict # value = {'Standard_HandlerVoid': (<Standard_HandlerStatus.Standard_HandlerVoid: 0>, None), 'Standard_HandlerJumped': (<Standard_HandlerStatus.Standard_HandlerJumped: 1>, None), 'Standard_HandlerProcessed': (<Standard_HandlerStatus.Standard_HandlerProcessed: 2>, None)}
    __members__: dict # value = {'Standard_HandlerVoid': <Standard_HandlerStatus.Standard_HandlerVoid: 0>, 'Standard_HandlerJumped': <Standard_HandlerStatus.Standard_HandlerJumped: 1>, 'Standard_HandlerProcessed': <Standard_HandlerStatus.Standard_HandlerProcessed: 2>}
    pass
class Standard_ImmutableObject(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_ImmutableObject' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_ImmutableObject' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_JsonKey():
    """
    Kind of key in Json string

    Members:

      Standard_JsonKey_None

      Standard_JsonKey_OpenChild

      Standard_JsonKey_CloseChild

      Standard_JsonKey_OpenContainer

      Standard_JsonKey_CloseContainer

      Standard_JsonKey_Quote

      Standard_JsonKey_SeparatorKeyToValue

      Standard_JsonKey_SeparatorValueToValue
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    Standard_JsonKey_CloseChild: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_CloseChild: 2>
    Standard_JsonKey_CloseContainer: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_CloseContainer: 4>
    Standard_JsonKey_None: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_None: 0>
    Standard_JsonKey_OpenChild: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_OpenChild: 1>
    Standard_JsonKey_OpenContainer: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_OpenContainer: 3>
    Standard_JsonKey_Quote: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_Quote: 5>
    Standard_JsonKey_SeparatorKeyToValue: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_SeparatorKeyToValue: 6>
    Standard_JsonKey_SeparatorValueToValue: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_SeparatorValueToValue: 7>
    __entries: dict # value = {'Standard_JsonKey_None': (<Standard_JsonKey.Standard_JsonKey_None: 0>, None), 'Standard_JsonKey_OpenChild': (<Standard_JsonKey.Standard_JsonKey_OpenChild: 1>, None), 'Standard_JsonKey_CloseChild': (<Standard_JsonKey.Standard_JsonKey_CloseChild: 2>, None), 'Standard_JsonKey_OpenContainer': (<Standard_JsonKey.Standard_JsonKey_OpenContainer: 3>, None), 'Standard_JsonKey_CloseContainer': (<Standard_JsonKey.Standard_JsonKey_CloseContainer: 4>, None), 'Standard_JsonKey_Quote': (<Standard_JsonKey.Standard_JsonKey_Quote: 5>, None), 'Standard_JsonKey_SeparatorKeyToValue': (<Standard_JsonKey.Standard_JsonKey_SeparatorKeyToValue: 6>, None), 'Standard_JsonKey_SeparatorValueToValue': (<Standard_JsonKey.Standard_JsonKey_SeparatorValueToValue: 7>, None)}
    __members__: dict # value = {'Standard_JsonKey_None': <Standard_JsonKey.Standard_JsonKey_None: 0>, 'Standard_JsonKey_OpenChild': <Standard_JsonKey.Standard_JsonKey_OpenChild: 1>, 'Standard_JsonKey_CloseChild': <Standard_JsonKey.Standard_JsonKey_CloseChild: 2>, 'Standard_JsonKey_OpenContainer': <Standard_JsonKey.Standard_JsonKey_OpenContainer: 3>, 'Standard_JsonKey_CloseContainer': <Standard_JsonKey.Standard_JsonKey_CloseContainer: 4>, 'Standard_JsonKey_Quote': <Standard_JsonKey.Standard_JsonKey_Quote: 5>, 'Standard_JsonKey_SeparatorKeyToValue': <Standard_JsonKey.Standard_JsonKey_SeparatorKeyToValue: 6>, 'Standard_JsonKey_SeparatorValueToValue': <Standard_JsonKey.Standard_JsonKey_SeparatorValueToValue: 7>}
    pass
class Standard_LicenseError(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_LicenseError' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_LicenseError' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_LicenseNotFound(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_LicenseNotFound' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_LicenseNotFound' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_MMgrRoot():
    """
    Root class for Open CASCADE mmemory managers. Defines only abstract interface functions.
    """
    def Allocate(self,theSize : int) -> capsule: 
        """
        Allocate specified number of bytes. The actually allocated space should be rounded up to double word size (4 bytes), as this is expected by implementation of some classes in OCC (e.g. TCollection_AsciiString)
        """
    def Free(self,thePtr : capsule) -> None: 
        """
        Frees previously allocated memory at specified address.
        """
    def Purge(self,isDestroyed : bool=False) -> int: 
        """
        Purge internally cached unused memory blocks (if any) by releasing them to the operating system. Must return non-zero if some memory has been actually released, or zero otherwise.
        """
    def Reallocate(self,thePtr : capsule,theSize : int) -> capsule: 
        """
        Reallocate previously allocated memory to contain at least theSize bytes. In case of success, new pointer is returned.
        """
    pass
class Standard_MMgrOpt(Standard_MMgrRoot):
    """
    Open CASCADE memory manager optimized for speed.
    """
    def Allocate(self,aSize : int) -> capsule: 
        """
        Allocate aSize bytes; see class description above
        """
    def Free(self,thePtr : capsule) -> None: 
        """
        Free previously allocated block. Note that block can not all blocks are released to the OS by this method (see class description)
        """
    def Purge(self,isDestroyed : bool) -> int: 
        """
        Release medium-sized blocks of memory in free lists to the system. Returns number of actually freed blocks
        """
    def Reallocate(self,thePtr : capsule,theSize : int) -> capsule: 
        """
        Reallocate previously allocated aPtr to a new size; new address is returned. In case that aPtr is null, the function behaves exactly as Allocate.
        """
    @staticmethod
    def SetCallBackFunction_s(pFunc : Any) -> None: 
        """
        SetCallBackFunction_s(pFunc: void (bool, void*, unsigned long, unsigned long)) -> None

        Set the callback function. You may pass 0 there to turn off the callback. The callback function, if set, will be automatically called from within Allocate and Free methods.
        """
    def __init__(self,aClear : bool=True,aMMap : bool=True,aCellSize : int=200,aNbPages : int=10000,aThreshold : int=40000) -> None: ...
    pass
class Standard_MultiplyDefined(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_MultiplyDefined' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_MultiplyDefined' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_Mutex():
    """
    Mutex: a class to synchronize access to shared data.
    """
    def Lock(self) -> None: 
        """
        Method to lock the mutex; waits until the mutex is released by other threads, locks it and then returns
        """
    def TryLock(self) -> bool: 
        """
        Method to test the mutex; if the mutex is not hold by other thread, locks it and returns True; otherwise returns False without waiting mutex to be released.
        """
    def Unlock(self) -> None: 
        """
        Method to unlock the mutex; releases it to other users

        Method to unlock the mutex; releases it to other users
        """
    def __init__(self) -> None: ...
    pass
class Standard_NegativeValue(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_NegativeValue' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_NegativeValue' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_NoMoreObject(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_NoMoreObject' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_NoMoreObject' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_NoSuchObject(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_NoSuchObject' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_NoSuchObject' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_NotImplemented(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_NotImplemented' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_NotImplemented' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_NullObject(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_NullObject' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_NullObject' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_NullValue(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_NullValue' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_NullValue' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_NumericError(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_NumericError' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_NumericError' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_OutOfMemory(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_OutOfMemory' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_OutOfMemory' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_OutOfRange(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_OutOfRange' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_OutOfRange' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_Overflow(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_Overflow' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_Overflow' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_Transient():
    """
    Abstract class which forms the root of the entire Transient class hierarchy.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> Standard_Type: 
        """
        Returns a type descriptor about this object.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,arg0 : Standard_Transient) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> Standard_Type: 
        """
        Returns type descriptor of Standard_Transient class
        """
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Standard_ProgramError(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_ProgramError' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_ProgramError' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_RangeError(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_RangeError' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_RangeError' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_ReadBuffer():
    """
    Auxiliary tool for buffered reading from input stream within chunks of constant size.
    """
    def Init(self,theDataLen : int,theChunkLen : int,theIsPartialPayload : bool=False) -> None: 
        """
        Initialize the buffer.
        """
    def IsDone(self) -> bool: 
        """
        Return TRUE if amount of read bytes is equal to requested length of entire data.
        """
    def __init__(self,theDataLen : int,theChunkLen : int,theIsPartialPayload : bool=False) -> None: ...
    pass
class Standard_ReadLineBuffer():
    """
    Auxiliary tool for buffered reading of lines from input stream.
    """
    def Clear(self) -> None: 
        """
        Clear buffer and cached values.
        """
    def IsMultilineMode(self) -> bool: 
        """
        Returns TRUE when the Multiline Mode is on; FALSE by default. Multiline modes joins several lines in file having \ at the end of line:
        """
    def SetMultilineMode(self,theMultilineMode : bool,theToPutGap : bool=True) -> None: 
        """
        Sets or unsets the multi-line mode.
        """
    def ToPutGapInMultiline(self) -> bool: 
        """
        Put gap space while merging lines within multiline syntax, so that the following sample: Will become "1/2/3 4/5/6" when flag is TRUE, and "1/2/35/5/6" otherwise.
        """
    def __init__(self,theMaxBufferSizeBytes : int) -> None: ...
    pass
class Standard_Static_Assert_true():
    """
    Static assert -- specialization for condition being true
    """
    def __init__(self) -> None: ...
    @staticmethod
    def assert_ok_s() -> None: ...
    pass
class Standard_Persistent(Standard_Transient):
    """
    Root of "persistent" classes, a legacy support of object oriented databases, now outdated.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    @property
    def TypeNum(self) -> int:
        """
        :type: int
        """
    @TypeNum.setter
    def TypeNum(self, arg1: int) -> None:
        pass
    pass
class Standard_Type(Standard_Transient):
    """
    This class provides legacy interface (type descriptor) to run-time type information (RTTI) for OCCT classes inheriting from Standard_Transient.This class provides legacy interface (type descriptor) to run-time type information (RTTI) for OCCT classes inheriting from Standard_Transient.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Name(self) -> str: 
        """
        Returns the given name of the class type (get_type_name)
        """
    def Parent(self) -> Standard_Type: 
        """
        Returns descriptor of the base class in the hierarchy
        """
    def Print(self,theStream : io.BytesIO) -> None: 
        """
        Prints type (address of descriptor + name) to a stream
        """
    @staticmethod
    def Register_s(theInfo : Any,theName : str,theSize : int,theParent : Standard_Type) -> Standard_Type: 
        """
        Register a type; returns either new or existing descriptor.
        """
    def Size(self) -> int: 
        """
        Returns the size of the class instance in bytes
        """
    @overload
    def SubType(self,theOther : Standard_Type) -> bool: 
        """
        Returns True if this type is the same as theOther, or inherits from theOther. Note that multiple inheritance is not supported.

        Returns True if this type is the same as theOther, or inherits from theOther. Note that multiple inheritance is not supported.
        """
    @overload
    def SubType(self,theOther : str) -> bool: ...
    def SystemName(self) -> str: 
        """
        Returns the system type name of the class (typeinfo.name)
        """
    def This(self) -> Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @staticmethod
    def get_type_descriptor_s() -> Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Standard_TypeMismatch(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_TypeMismatch' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_TypeMismatch' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Standard_UUID():
    def __init__(self) -> None: ...
    pass
class Standard_Underflow(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Standard', '__weakref__': <attribute '__weakref__' of 'Standard_Underflow' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Standard_Underflow' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
def ACos(arg0 : float) -> float:
    pass
def ACosApprox(arg0 : float) -> float:
    pass
def ACosh(arg0 : float) -> float:
    pass
def ASin(arg0 : float) -> float:
    pass
def ASinh(Value : float) -> float:
    pass
def ATan(Value : float) -> float:
    pass
def ATan2(arg0 : float,arg1 : float) -> float:
    pass
def ATanh(arg0 : float) -> float:
    pass
@overload
def Abs(Value : int) -> int:
    pass
@overload
def Abs(Value : float) -> float:
    pass
def Ceiling(Value : float) -> float:
    pass
def Cos(Value : float) -> float:
    pass
def Cosh(arg0 : float) -> float:
    pass
def Epsilon(Value : float) -> float:
    pass
def Exp(Value : float) -> float:
    pass
def Floor(Value : float) -> float:
    pass
def IntToReal(Value : int) -> float:
    pass
def IntegerFirst() -> int:
    pass
def IntegerLast() -> int:
    pass
def IntegerPart(Value : float) -> float:
    pass
def IntegerSize() -> int:
    pass
def IsAlphabetic(me : str) -> bool:
    pass
def IsAlphanumeric(me : str) -> bool:
    pass
def IsAnAscii(achar : str) -> bool:
    pass
def IsControl(me : str) -> bool:
    pass
def IsDigit(me : str) -> bool:
    pass
@overload
def IsEqual(theOne : str,theTwo : str) -> bool:
    """
    Returns Standard_True if two strings are equal
    """
@overload
def IsEqual(One : str,Two : str) -> bool:
    pass
@overload
def IsEqual(Value1 : float,Value2 : float) -> bool:
    pass
def IsEven(Value : int) -> bool:
    pass
def IsGraphic(me : str) -> bool:
    pass
def IsLowerCase(me : str) -> bool:
    pass
def IsOdd(Value : int) -> bool:
    pass
def IsPrintable(me : str) -> bool:
    pass
def IsPunctuation(me : str) -> bool:
    pass
def IsSpace(me : str) -> bool:
    pass
def IsUpperCase(me : str) -> bool:
    pass
def IsXDigit(me : str) -> bool:
    pass
def Log(arg0 : float) -> float:
    pass
def Log10(Value : float) -> float:
    pass
def LowerCase(me : str) -> str:
    pass
@overload
def Max(Val1 : int,Val2 : int) -> int:
    pass
@overload
def Max(Val1 : float,Val2 : float) -> float:
    pass
@overload
def Min(Val1 : int,Val2 : int) -> int:
    pass
@overload
def Min(Val1 : float,Val2 : float) -> float:
    pass
def Modulus(Value : int,Divisor : int) -> int:
    pass
def NextAfter(arg0 : float,arg1 : float) -> float:
    pass
def Pow(Value : float,P : float) -> float:
    pass
def RealDigits() -> int:
    pass
def RealEpsilon() -> float:
    pass
def RealFirst() -> float:
    pass
def RealFirst10Exp() -> int:
    pass
def RealLast() -> float:
    pass
def RealLast10Exp() -> int:
    pass
def RealMantissa() -> int:
    pass
def RealPart(Value : float) -> float:
    pass
def RealRadix() -> int:
    pass
def RealSize() -> int:
    pass
def RealSmall() -> float:
    pass
def RealToInt(theValue : float) -> int:
    pass
def RealToShortReal(theVal : float) -> float:
    pass
def Round(Value : float) -> float:
    pass
def ShortRealDigits() -> int:
    pass
def ShortRealEpsilon() -> float:
    pass
def ShortRealFirst() -> float:
    pass
def ShortRealFirst10Exp() -> int:
    pass
def ShortRealLast() -> float:
    pass
def ShortRealLast10Exp() -> int:
    pass
def ShortRealMantissa() -> int:
    pass
def ShortRealRadix() -> int:
    pass
def ShortRealSize() -> int:
    pass
def ShortRealSmall() -> float:
    pass
def Sign(a : float,b : float) -> float:
    """
    Returns |a| if b >= 0; -|a| if b < 0.
    """
def Sin(Value : float) -> float:
    pass
def Sinh(arg0 : float) -> float:
    pass
def Sqrt(arg0 : float) -> float:
    pass
@overload
def Square(Value : int) -> int:
    pass
@overload
def Square(Value : float) -> float:
    pass
def Standard_ASSERT_DO_NOTHING() -> None:
    """
    This header file defines a set of ASSERT macros intended for use in algorithms for debugging purposes and as a tool to organise checks for abnormal situations in the uniform way.
    """
def Standard_Atomic_CompareAndSwap(theValue : int,theOldValue : int,theNewValue : int) -> bool:
    """
    Perform an atomic compare and swap. That is, if the current value of *theValue is theOldValue, then write theNewValue into *theValue.

    Perform an atomic compare and swap. That is, if the current value of *theValue is theOldValue, then write theNewValue into *theValue.
    """
def Standard_Atomic_Decrement(theValue : int) -> int:
    """
    Decrements atomically integer variable pointed by theValue and returns resulting decremented value.

    Decrements atomically integer variable pointed by theValue and returns resulting decremented value.
    """
def Standard_Atomic_Increment(theValue : int) -> int:
    """
    Increments atomically integer variable pointed by theValue and returns resulting incremented value.

    Increments atomically integer variable pointed by theValue and returns resulting incremented value.
    """
def Tan(Value : float) -> float:
    pass
def Tanh(Value : float) -> float:
    pass
def ToCharacter(achar : str) -> str:
    pass
def ToExtCharacter(achar : str) -> str:
    pass
def UpperCase(me : str) -> str:
    pass
Standard_HandlerJumped: OCP.Standard.Standard_HandlerStatus # value = <Standard_HandlerStatus.Standard_HandlerJumped: 1>
Standard_HandlerProcessed: OCP.Standard.Standard_HandlerStatus # value = <Standard_HandlerStatus.Standard_HandlerProcessed: 2>
Standard_HandlerVoid: OCP.Standard.Standard_HandlerStatus # value = <Standard_HandlerStatus.Standard_HandlerVoid: 0>
Standard_JsonKey_CloseChild: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_CloseChild: 2>
Standard_JsonKey_CloseContainer: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_CloseContainer: 4>
Standard_JsonKey_None: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_None: 0>
Standard_JsonKey_OpenChild: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_OpenChild: 1>
Standard_JsonKey_OpenContainer: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_OpenContainer: 3>
Standard_JsonKey_Quote: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_Quote: 5>
Standard_JsonKey_SeparatorKeyToValue: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_SeparatorKeyToValue: 6>
Standard_JsonKey_SeparatorValueToValue: OCP.Standard.Standard_JsonKey # value = <Standard_JsonKey.Standard_JsonKey_SeparatorValueToValue: 7>



import OCP.GeomLProp
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.GeomAbs
import OCP.gp
import OCP.Geom
__all__  = [
"GeomLProp",
"GeomLProp_CLProps",
"GeomLProp_CurveTool",
"GeomLProp_SLProps",
"GeomLProp_SurfaceTool"
]
class GeomLProp():
    """
    These global functions compute the degree of continuity of a 3D curve built by concatenation of two other curves (or portions of curves) at their junction point.
    """
    @staticmethod
    @overload
    def Continuity_s(C1 : OCP.Geom.Geom_Curve,C2 : OCP.Geom.Geom_Curve,u1 : float,u2 : float,r1 : bool,r2 : bool,tl : float,ta : float) -> OCP.GeomAbs.GeomAbs_Shape: 
        """
        Computes the regularity at the junction between C1 and C2. The booleans r1 and r2 are true if the curves must be taken reversed. The point u1 on C1 and the point u2 on C2 must be confused. tl and ta are the linear and angular tolerance used two compare the derivative.

        The same as preceding but using the standard tolerances from package Precision.
        """
    @staticmethod
    @overload
    def Continuity_s(C1 : OCP.Geom.Geom_Curve,C2 : OCP.Geom.Geom_Curve,u1 : float,u2 : float,r1 : bool,r2 : bool) -> OCP.GeomAbs.GeomAbs_Shape: ...
    def __init__(self) -> None: ...
    pass
class GeomLProp_CLProps():
    def CentreOfCurvature(self,P : OCP.gp.gp_Pnt) -> None: 
        """
        Returns the centre of curvature <P>.
        """
    def Curvature(self) -> float: 
        """
        Returns the curvature.
        """
    def D1(self) -> OCP.gp.gp_Vec: 
        """
        Returns the first derivative. The derivative is computed if it has not been yet.
        """
    def D2(self) -> OCP.gp.gp_Vec: 
        """
        Returns the second derivative. The derivative is computed if it has not been yet.
        """
    def D3(self) -> OCP.gp.gp_Vec: 
        """
        Returns the third derivative. The derivative is computed if it has not been yet.
        """
    def IsTangentDefined(self) -> bool: 
        """
        Returns True if the tangent is defined. For example, the tangent is not defined if the three first derivatives are all null.
        """
    def Normal(self,N : OCP.gp.gp_Dir) -> None: 
        """
        Returns the normal direction <N>.
        """
    def SetCurve(self,C : OCP.Geom.Geom_Curve) -> None: 
        """
        Initializes the local properties of the curve for the new curve.
        """
    def SetParameter(self,U : float) -> None: 
        """
        Initializes the local properties of the curve for the parameter value <U>.
        """
    def Tangent(self,D : OCP.gp.gp_Dir) -> None: 
        """
        output the tangent direction <D>
        """
    def Value(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the Point.
        """
    @overload
    def __init__(self,C : OCP.Geom.Geom_Curve,N : int,Resolution : float) -> None: ...
    @overload
    def __init__(self,C : OCP.Geom.Geom_Curve,U : float,N : int,Resolution : float) -> None: ...
    @overload
    def __init__(self,N : int,Resolution : float) -> None: ...
    pass
class GeomLProp_CurveTool():
    @staticmethod
    def Continuity_s(C : OCP.Geom.Geom_Curve) -> int: 
        """
        returns the order of continuity of the curve <C>. returns 1 : first derivative only is computable returns 2 : first and second derivative only are computable. returns 3 : first, second and third are computable.
        """
    @staticmethod
    def D1_s(C : OCP.Geom.Geom_Curve,U : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec) -> None: 
        """
        Computes the point <P> and first derivative <V1> of parameter <U> on the curve <C>.
        """
    @staticmethod
    def D2_s(C : OCP.Geom.Geom_Curve,U : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec) -> None: 
        """
        Computes the point <P>, the first derivative <V1> and second derivative <V2> of parameter <U> on the curve <C>.
        """
    @staticmethod
    def D3_s(C : OCP.Geom.Geom_Curve,U : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec,V3 : OCP.gp.gp_Vec) -> None: 
        """
        Computes the point <P>, the first derivative <V1>, the second derivative <V2> and third derivative <V3> of parameter <U> on the curve <C>.
        """
    @staticmethod
    def FirstParameter_s(C : OCP.Geom.Geom_Curve) -> float: 
        """
        returns the first parameter bound of the curve.
        """
    @staticmethod
    def LastParameter_s(C : OCP.Geom.Geom_Curve) -> float: 
        """
        returns the last parameter bound of the curve. FirstParameter must be less than LastParamenter.
        """
    @staticmethod
    def Value_s(C : OCP.Geom.Geom_Curve,U : float,P : OCP.gp.gp_Pnt) -> None: 
        """
        Computes the point <P> of parameter <U> on the curve <C>.
        """
    def __init__(self) -> None: ...
    pass
class GeomLProp_SLProps():
    def CurvatureDirections(self,MaxD : OCP.gp.gp_Dir,MinD : OCP.gp.gp_Dir) -> None: 
        """
        Returns the direction of the maximum and minimum curvature <MaxD> and <MinD>
        """
    def D1U(self) -> OCP.gp.gp_Vec: 
        """
        Returns the first U derivative. The derivative is computed if it has not been yet.
        """
    def D1V(self) -> OCP.gp.gp_Vec: 
        """
        Returns the first V derivative. The derivative is computed if it has not been yet.
        """
    def D2U(self) -> OCP.gp.gp_Vec: 
        """
        Returns the second U derivatives The derivative is computed if it has not been yet.
        """
    def D2V(self) -> OCP.gp.gp_Vec: 
        """
        Returns the second V derivative. The derivative is computed if it has not been yet.
        """
    def DUV(self) -> OCP.gp.gp_Vec: 
        """
        Returns the second UV cross-derivative. The derivative is computed if it has not been yet.
        """
    def GaussianCurvature(self) -> float: 
        """
        Returns the Gaussian curvature
        """
    def IsCurvatureDefined(self) -> bool: 
        """
        returns True if the curvature is defined.
        """
    def IsNormalDefined(self) -> bool: 
        """
        Tells if the normal is defined.
        """
    def IsTangentUDefined(self) -> bool: 
        """
        returns True if the U tangent is defined. For example, the tangent is not defined if the two first U derivatives are null.
        """
    def IsTangentVDefined(self) -> bool: 
        """
        returns if the V tangent is defined. For example, the tangent is not defined if the two first V derivatives are null.
        """
    def IsUmbilic(self) -> bool: 
        """
        returns True if the point is umbilic (i.e. if the curvature is constant).
        """
    def MaxCurvature(self) -> float: 
        """
        Returns the maximum curvature
        """
    def MeanCurvature(self) -> float: 
        """
        Returns the mean curvature.
        """
    def MinCurvature(self) -> float: 
        """
        Returns the minimum curvature
        """
    def Normal(self) -> OCP.gp.gp_Dir: 
        """
        Returns the normal direction.
        """
    def SetParameters(self,U : float,V : float) -> None: 
        """
        Initializes the local properties of the surface S for the new parameter values (<U>, <V>).
        """
    def SetSurface(self,S : OCP.Geom.Geom_Surface) -> None: 
        """
        Initializes the local properties of the surface S for the new surface.
        """
    def TangentU(self,D : OCP.gp.gp_Dir) -> None: 
        """
        Returns the tangent direction <D> on the iso-V.
        """
    def TangentV(self,D : OCP.gp.gp_Dir) -> None: 
        """
        Returns the tangent direction <D> on the iso-V.
        """
    def Value(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the point.
        """
    @overload
    def __init__(self,S : OCP.Geom.Geom_Surface,U : float,V : float,N : int,Resolution : float) -> None: ...
    @overload
    def __init__(self,S : OCP.Geom.Geom_Surface,N : int,Resolution : float) -> None: ...
    @overload
    def __init__(self,N : int,Resolution : float) -> None: ...
    pass
class GeomLProp_SurfaceTool():
    @staticmethod
    def Bounds_s(S : OCP.Geom.Geom_Surface) -> tuple[float, float, float, float]: 
        """
        returns the bounds of the Surface.
        """
    @staticmethod
    def Continuity_s(S : OCP.Geom.Geom_Surface) -> int: 
        """
        returns the order of continuity of the Surface <S>. returns 1 : first derivative only is computable returns 2 : first and second derivative only are computable.
        """
    @staticmethod
    def D1_s(S : OCP.Geom.Geom_Surface,U : float,V : float,P : OCP.gp.gp_Pnt,D1U : OCP.gp.gp_Vec,D1V : OCP.gp.gp_Vec) -> None: 
        """
        Computes the point <P> and first derivative <D1*> of parameter <U> and <V> on the Surface <S>.
        """
    @staticmethod
    def D2_s(S : OCP.Geom.Geom_Surface,U : float,V : float,P : OCP.gp.gp_Pnt,D1U : OCP.gp.gp_Vec,D1V : OCP.gp.gp_Vec,D2U : OCP.gp.gp_Vec,D2V : OCP.gp.gp_Vec,DUV : OCP.gp.gp_Vec) -> None: 
        """
        Computes the point <P>, the first derivative <D1*> and second derivative <D2*> of parameter <U> and <V> on the Surface <S>.
        """
    @staticmethod
    def DN_s(S : OCP.Geom.Geom_Surface,U : float,V : float,IU : int,IV : int) -> OCP.gp.gp_Vec: ...
    @staticmethod
    def Value_s(S : OCP.Geom.Geom_Surface,U : float,V : float,P : OCP.gp.gp_Pnt) -> None: 
        """
        Computes the point <P> of parameter <U> and <V> on the Surface <S>.
        """
    def __init__(self) -> None: ...
    pass



import OCP.RWStl
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.OSD
import io
import OCP.gp
import OCP.Message
import OCP.Standard
import OCP.Poly
__all__  = [
"RWStl",
"RWStl_Reader"
]
class RWStl():
    """
    This class provides methods to read and write triangulation from / to the STL files.
    """
    @staticmethod
    def ReadAscii_s(thePath : OCP.OSD.OSD_Path,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> OCP.Poly.Poly_Triangulation: 
        """
        Read triangulation from an Ascii STL file In case of error, returns Null handle.
        """
    @staticmethod
    def ReadBinary_s(thePath : OCP.OSD.OSD_Path,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> OCP.Poly.Poly_Triangulation: 
        """
        Read triangulation from a binary STL file In case of error, returns Null handle.
        """
    @staticmethod
    @overload
    def ReadFile_s(theFile : OCP.OSD.OSD_Path,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> OCP.Poly.Poly_Triangulation: 
        """
        Read specified STL file and returns its content as triangulation. In case of error, returns Null handle.

        Read specified STL file and returns its content as triangulation. In case of error, returns Null handle.

        Read specified STL file and returns its content as triangulation.

        Read specified STL file and fills triangulation list for multi-domain case.
        """
    @staticmethod
    @overload
    def ReadFile_s(theFile : str,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> OCP.Poly.Poly_Triangulation: ...
    @staticmethod
    @overload
    def ReadFile_s(theFile : str,theMergeAngle : float,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> OCP.Poly.Poly_Triangulation: ...
    @staticmethod
    @overload
    def ReadFile_s(theFile : str,theMergeAngle : float,theTriangList : Any,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: ...
    @staticmethod
    def WriteAscii_s(theMesh : OCP.Poly.Poly_Triangulation,thePath : OCP.OSD.OSD_Path,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: 
        """
        write the meshing in a file following the Ascii format of an STL file. Returns false if the cannot be opened;
        """
    @staticmethod
    def WriteBinary_s(theMesh : OCP.Poly.Poly_Triangulation,thePath : OCP.OSD.OSD_Path,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: 
        """
        Write triangulation to binary STL file. binary format of an STL file. Returns false if the cannot be opened;
        """
    def __init__(self) -> None: ...
    pass
class RWStl_Reader(OCP.Standard.Standard_Transient):
    """
    An abstract class implementing procedure to read STL file.
    """
    def AddNode(self,thePnt : OCP.gp.gp_XYZ) -> int: 
        """
        Callback function to be implemented in descendant. Should create new node with specified coordinates in the target model, and return its ID as integer.
        """
    def AddSolid(self) -> None: 
        """
        Callback function to be implemented in descendant. Should create a new triangulation for a solid in multi-domain case.
        """
    def AddTriangle(self,theN1 : int,theN2 : int,theN3 : int) -> None: 
        """
        Callback function to be implemented in descendant. Should create new triangle built on specified nodes in the target model.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsAscii(self,theStream : io.BytesIO,isSeekgAvailable : bool) -> bool: 
        """
        Guess whether the stream is an Ascii STL file, by analysis of the first bytes (~200). If the stream does not support seekg() then the parameter isSeekgAvailable should be passed as 'false', in this case the function attempts to put back the read symbols to the stream which thus must support ungetc(). Returns true if the stream seems to contain Ascii STL.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MergeAngle(self) -> float: 
        """
        Return merge tolerance; M_PI/2 by default - all nodes are merged regardless angle between triangles.
        """
    def MergeTolerance(self) -> float: 
        """
        Return linear merge tolerance; 0.0 by default (only 3D points with exactly matching coordinates are merged).
        """
    def Read(self,theFile : str,theProgress : OCP.Message.Message_ProgressRange) -> bool: 
        """
        Reads data from STL file (either binary or Ascii). This function supports reading multi-domain STL files formed by concatenation of several "plain" files. The mesh nodes are not merged between domains. Unicode paths can be given in UTF-8 encoding. Format is recognized automatically by analysis of the file header. Returns true if success, false on error or user break.
        """
    def ReadBinary(self,theStream : io.BytesIO,theProgress : OCP.Message.Message_ProgressRange) -> bool: 
        """
        Reads STL data from binary stream. The stream must be opened in binary mode. Stops after reading the number of triangles recorded in the file header. Returns true if success, false on error or user break.
        """
    def SetMergeAngle(self,theAngleRad : float) -> None: 
        """
        Set merge angle in radians. Specify something like M_PI/4 (45 degrees) to avoid merge nodes between triangles at sharp corners.
        """
    def SetMergeTolerance(self,theTolerance : float) -> None: 
        """
        Set linear merge tolerance.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
